==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Image/Gui/Resources/translations/Image_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Изображение</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Создать плоскость изображения ...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Создать двухмерное изображение в 3D-пространстве</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>Cоздание плоского изображения в 3D пространстве</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Изображение</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Открыть...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Открыть изображение</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+318"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Неопределенный тип цвета пространства для просмотра изображений</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>Растровый формат изображения</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp; Растянуть изображения</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>Растянуть изображение по размеру вида</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>&amp; масштаб 1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Отображает изображение в масштабе 1: 1 </translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Исходный цвета</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Изображение в исходных цветах</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Оживить цвет</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Показать изображение в ярком цвете(ах)</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Стандарт</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Готово...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>Серый</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>Масштаб</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>за пределами изображения</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Просмотр изображения</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Изображения (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Выберите файл изображения, чтобы открыть</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Изображения</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Все файлы</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Ошибка при открытии изображения</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Не удалось загрузить выбранное изображение</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Изображение</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Image/Gui/Resources/translations/Image_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+94"/>
      <source>Image</source>
      <translation>Изображение</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Создать плоскость изображения ...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Создать двухмерное изображение в 3D-пространстве</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="obsolete">Cоздание плоского изображения в 3D пространстве</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-44"/>
      <source>Image</source>
      <translation>Изображение</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Открыть...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Открыть изображение</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+326"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Неопределенный тип цвета пространства для просмотра изображений</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>Image pixel format</source>
      <translation>Растровый формат изображения</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Выберите ориентацию</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">Плоскость XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">Плоскость XZ</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">Плоскость YZ</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Развернуть направление</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Смещение:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>&amp; Растянуть изображения</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Растянуть изображение по размеру вида</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp; масштаб 1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Отображает изображение в масштабе 1: 1 </translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="obsolete">&amp;Исходный цвета</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="obsolete">Изображение в исходных цветах</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="obsolete">&amp;Оживить цвет</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="obsolete">Показать изображение в ярком цвете(ах)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Стандарт</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>Ready...</source>
      <translation>Готово...</translation>
    </message>
    <message>
      <location line="+375"/>
      <source>grey</source>
      <translation>Серый</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Масштаб</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>за пределами изображения</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="obsolete">Просмотр изображения</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+117"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Изображения (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location line="-99"/>
      <location line="+41"/>
      <location line="+57"/>
      <source>Choose an image file to open</source>
      <translation>Выберите файл изображения, чтобы открыть</translation>
    </message>
    <message>
      <location line="-105"/>
      <location line="+41"/>
      <source>Images</source>
      <translation>Изображения</translation>
    </message>
    <message>
      <location line="-36"/>
      <location line="+41"/>
      <source>All files</source>
      <translation>Все файлы</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error open image</source>
      <translation>Ошибка при открытии изображения</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the choosen image</source>
      <translation>Не удалось загрузить выбранное изображение</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Изображение</translation>
    </message>
  </context>
</TS>
